@@ -17,7 +17,7 @@
 /*
  *
  * @author Mladen Turk
- * @version $Revision: 562478 $, $Date: 2007-08-03 16:33:51 +0200 (Fri, 03 Aug 2007) $
+ * @version $Revision: 907567 $, $Date: 2010-02-08 08:22:04 +0100 (Mon, 08 Feb 2010) $
  */
 
 #include "tcn.h"
@@ -76,6 +76,7 @@ void sp_network_dump_statistics()
 
 #endif /* TCN_DO_STATISTICS */
 
+extern apr_pool_t *tcn_global_pool;
 static apr_status_t sp_socket_cleanup(void *data)
 {
     tcn_socket_t *s = (tcn_socket_t *)data;
@@ -409,7 +410,7 @@ TCN_IMPLEMENT_CALL(jlong, Socket, accept)(TCN_STDARGS, jlong sock)
     }
     return P2J(a);
 cleanup:
-    if (p && s->sock)
+    if (tcn_global_pool && p && s->sock)
         apr_pool_destroy(p);
     return 0;
 }
@@ -1106,7 +1107,6 @@ TCN_IMPLEMENT_CALL(jint, Socket, optSet)(TCN_STDARGS, jlong sock,
 
     UNREFERENCED(o);
     if (!s->sock) {
-        tcn_ThrowAPRException(e, APR_ENOTSOCK);
         return APR_ENOTSOCK;
     }
     else
@@ -1120,7 +1120,7 @@ TCN_IMPLEMENT_CALL(jint, Socket, optGet)(TCN_STDARGS, jlong sock,
     apr_int32_t on = 0;
 
     UNREFERENCED(o);
-    if (s->sock)
+    if (!s->sock)
         tcn_ThrowAPRException(e, APR_ENOTSOCK);
     else {
         TCN_THROW_IF_ERR((*s->net->opt_get)(s->opaque, (apr_int32_t)opt,
